@@ -24,6 +24,22 @@ from operator import itemgetter
 from mm.exceptions import MMException
 from jinja2 import Environment, FileSystemLoader
 
+# these keyring imports are for pyinstaller
+try:
+    import keyring
+except:
+    pass
+try:
+    import gnomekeyring
+except:
+    pass
+
+if config.is_windows:
+    try:
+        import keyring.backends._win_crypto as _win_crypto
+    except:
+        pass
+
 import jinja2.ext
 import jinja2htmlcompress
 from jinja2htmlcompress import HTMLCompress
@@ -167,11 +183,13 @@ def decode(key, enc):
 def put_password_by_key(key, password):
     use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', True)
     if use_keyring:
-        if sys.platform == 'linux2':
+
+        if config.is_linux:
             import gnomekeyring
         else:
             import keyring
-        if sys.platform == 'linux2':
+
+        if config.is_linux:
             try:
                 gnomekeyring.set_network_password_sync(None, key, 'MavensMate: '+key,
                     None, None, None, None, 0, password)
@@ -188,11 +206,12 @@ def put_password_by_key(key, password):
 def get_password_by_key(key):
     use_keyring = config.connection.get_plugin_client_setting('mm_use_keyring', True)
     if use_keyring:
-        if sys.platform == 'linux2':
+        if config.is_linux:
             import gnomekeyring
         else:
             import keyring
-        if sys.platform == 'linux2':
+
+        if config.is_linux:
             try:
                 items = gnomekeyring.find_network_password_sync(key, 'MavensMate: '+key)
                 return items[0]['password']
@@ -915,20 +934,16 @@ def generate_error_response(message, dump_to_json=True, verbose=False):
                 #todo: support windows and linux
             except:
                 pass
-            # try to get the executable version
-            try:
-                if sys.platform == 'darwin':
-                    dic = plistlib.readPlist('/Applications/MavensMate.app/Contents/Info.plist')
-                    if 'CFBundleVersion' in dic:
-                        stack_trace += ', MavensMate ' + dic['CFBundleVersion']
-            except:
-                pass
-
+            
         if 'nodename nor servname provided' in stack_trace:
             message = 'No internet connection'
 
+        stack_trace = re.sub(r'/Users\/.+?.pyz\/', '', stack_trace)
+        stack_trace = re.sub(r'C:\\Users\\.+?.pyz\/', '', stack_trace)
+
         config.logger.exception("[MAVENSMATE CAUGHT ERROR]")
         config.logger.debug(stack_trace)
+
         if config.connection.verbose or verbose:
             res = {
                 "success"       : False,
@@ -947,6 +962,8 @@ def generate_error_response(message, dump_to_json=True, verbose=False):
         else:
             return res
     except:
+        stack_trace = re.sub(r'/Users\/.+?.pyz\/', '', stack_trace)
+        stack_trace = re.sub(r'C:\\Users\\.+?.pyz\/', '', stack_trace)
         res = {
             "success"       : False,
             "body_type"     : "text",
@@ -963,7 +980,10 @@ def format_exception(exc_info=None):
         exc_info = sys.exc_info()
     out = StringIO()
     traceback.print_exception(*exc_info, **dict(file=out))
-    return out.getvalue()
+    formatted_exception = out.getvalue()
+    formatted_exception = re.sub(r'/Users\/.+?.pyz\/', '', formatted_exception)
+    formatted_exception = re.sub(r'C:\\Users\\.+?.pyz\/', '', formatted_exception)
+    return formatted_exception
 
 def prepare_for_metadata_tree(metadata_list):
     apex_types = ['ApexClass', 'ApexComponent', 'ApexTrigger', 'ApexPage', 'StaticResource']
@@ -1129,26 +1149,20 @@ def get_metadata_hash(selected_files=[]):
                 meta_type = metadata_definition["xmlName"]
 
         if meta_type not in meta_hash: #key isn't there yet, put it in
-            if metadata_definition['inFolder']:
-                arr = f.split("/")
-                if arr[len(arr)-2] != metadata_definition['directoryName']:
-                    meta_hash[meta_type] = [arr[len(arr)-2]+"/"+base_name_no_ext] #file name with no extension
-                else:
-                    meta_hash[meta_type] = [base_name_no_ext]
+            meta_hash[meta_type] = [];        
+            
+        #key is there, let's add metadata to it
+        meta_array = meta_hash[meta_type] #get the existing array
+        if metadata_definition['inFolder']:
+            arr = f.split("\\") if sys.platform == "win32" else f.split("/")
+            if arr[-2] != metadata_definition['directoryName']:
+                meta_array.append(arr[-2]+"/"+base_name_no_ext) #file name with no extension
             else:
-                meta_hash[meta_type] = [base_name_no_ext]
-        else: #key is there, let's add metadata to it
-            meta_array = meta_hash[meta_type] #get the existing array
-            if metadata_definition['inFolder']:
-                arr = f.split("/")
-                if arr[len(arr)-2] != metadata_definition['directoryName']:
-                    meta_array.append(arr[len(arr)-2]+"/"+base_name_no_ext) #file name with no extension
-                else:
-                    meta_array.append(base_name_no_ext) #add the new piece of metadata
-            else:
-                meta_array.append(base_name_no_ext) #file name with no extension
-
-            meta_hash[meta_type] = meta_array #replace the key
+                meta_array.append(base_name_no_ext) #add the new piece of metadata
+        else:
+            meta_array.append(base_name_no_ext) #file name with no extension
+        
+        meta_hash[meta_type] = meta_array #replace the key
 
     return meta_hash
 
